@@ -13,6 +13,13 @@
 ### ___Note___ we have some of these headers __MESS__
 ### But we leave it because of RCS {rather dismantle everything into 4-6 pieces
 
+## A fast substitute for structure() *when* we don't need to special case for factor, .Dim, ...
+struct <- function(x, ...) `attributes<-`(x, c(attributes(x), list(...)))
+
+##' list_(a, b, cc)  creates a *named* list  using the actual arguments' names
+list_ <- function(...)
+   `names<-`(list(...), vapply(sys.call()[-1L], as.character, ""))
+
 ##-#### Vector, Matrix (or higher Array) stuff ########
 ##-###  -------------------------------------- ########
 
@@ -32,12 +39,10 @@ last <- function(x, length.out = 1, na.rm = FALSE)
     x[sign(length.out)*(n-abs(length.out)+1):n]
 }
 
-empty.dimnames <- function(a)
-{
+empty.dimnames <- function(a) {
     ## 'Remove' all dimension names from an array for compact printing.
     n <- length(da <- dim(a))
-    if(n == 0) return(a)
-    dimnames(a) <- lapply(1:n, function(i) rep.int("", da[i]))
+    if(n) dimnames(a) <- lapply(1:n, function(i) rep.int("", da[i]))
     a
 }
 
@@ -211,7 +216,7 @@ histBxp <-
   ##-- but you should leave some white space -> scale down
   ##-- The scaling factor is really a  KLUDGE but works for a wide range!
   p.hboxp(x, scale.r(par("usr")[3], 0, ## ph, 8.5.00: changed f=.9 to f=.8
-		     f = .8 - max(0, .15 - width)*(1+(par("mfg")[3] >= 3))),
+		     fact = .8 - max(0, .15 - width)*(1+(par("mfg")[3] >= 3))),
 	  boxcol = boxcol, medcol = medcol,
 	  medlwd = medlwd, whisklty = whisklty, staplelty = staplelty)
 }
@@ -564,8 +569,8 @@ rDatetime <- function(n, min = "1900-01-01", max = "2100-12-31") {
         max <- as.POSIXct(max)
     else stop("'max' must be string (coercable to \"POSIXct\") or \"POSIXt\" object")
     stopifnot(length(min) == 1, length(max) == 1)
-    structure(runif(n, as.numeric(min), as.numeric(max)),
-              class = c("POSIXct", "POSIXt"), tzone = "")
+    struct(runif(n, as.numeric(min), as.numeric(max)),
+           class = c("POSIXct", "POSIXt"), tzone = "")
 }
 
 ###
@@ -1022,7 +1027,7 @@ prt.DEBUG <- function(..., LEVEL = 1) {
 ## --> ../man/read.org.table.Rd
 read.org.table <- function(file, header = TRUE, skip = 0,
                            encoding = "native", fileEncoding = "",
-                           text, ...) {
+                           text, quiet=FALSE, ...) {
     ## file - text   handling --- cut'n'paste from read.table()'s header
     if (missing(file) && !missing(text)) {
 	file <- textConnection(text, encoding = "UTF-8")
@@ -1058,8 +1063,18 @@ read.org.table <- function(file, header = TRUE, skip = 0,
     }
     ## drop empty lines at end only
     while(grepl("^ *$", tail(ll, 1L))) ll <- ll[-length(ll)]
+    nent <- count.fields(textConnection(ll), sep="|")
+    ok <- nent == (p <- length(col.names))
+    nrows <- if(all(ok)) length(ok)
+             else match(FALSE, ok) - 1L # 1..n, where n+1 contains the first non-match
+    if("nrows" %in% ...names())
+        nrows <- min(nrows, list(...)$nrows)
+    else if(!quiet && nrows < 0.95*length(nent))
+        message(
+            sprintf("Will read the first %d rows (of each %d columns) of %d (non-empty non-header) lines",
+                    nrows, p, length(nent)))
     f.ll <- textConnection(ll)# , encoding = "UTF-8"  is *NOT* good
     on.exit(close(f.ll))
     read.table(f.ll, header=FALSE, sep = "|",
-               col.names = col.names, ...) # , encoding = "UTF-8" *not* good
+               col.names = col.names, nrows=nrows, ...) # , encoding = "UTF-8" *not* good
 }
